==> iwrite-2.0.1.0.tar.gz: iwrite-2.0.1.0/src/report_util.h <==
/* 
vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler 
*/
/*
Copyright (c) 2016, iwrite authors 
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#ifndef __report_util_h__

#include "global_common.h"
#include "iwr_page.h"
#include "goop.h"

enum report_style
{
  style_unassigned= 0,
  style_layout,
  style_export,
  style_label
};

enum report_format
{
  format_pdf
};

extern enum report_style
report_util_convert_text_to_style(
  char const*                           i_style);

extern char*
report_util_get_report_filename(
  char const*                           i_reportfile);

extern int
report_util_open_report(
  GError**                              o_error,
  enum report_style*                    o_style,
  struct xml**                          o_xml,
  char const*                           i_reportfile);

extern int
report_util_run(
  GError**                              o_error,
  char const*                           i_reportfile,
  char const*                           i_password,
  struct goop const*const               i_goop);

#define __report_util_h__
#endif

==> iwrite-3.1.1.0.tar.gz: iwrite-3.1.1.0/src/report_util.h <==
/* 
vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler 
*/
/*
Copyright (c) 2016, iwrite authors 
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#ifndef __report_util_h__

#include "global_common.h"
#include "database_aspect.h"
#include "iwr_page.h"
#include "goop.h"

enum report_style
{
  style_unassigned= 0,
  style_layout,
  style_export,
  style_label
};

enum report_format
{
  format_pdf
};

extern enum report_style
report_util_convert_text_to_style(
  char const*                           i_style);

extern char*
report_util_get_report_filename(
  char const*                           i_reportfile);

extern int
report_util_open_report(
  GError**                              o_error,
  enum report_style*                    o_style,
  struct xml**                          o_xml,
  char const*                           i_reportfile);

extern int
report_util_resolve_password(
  struct database_aspect*const          io_aspect,
  int const                             i_interactive);

extern int
report_util_run(
  GError**                              o_error,
  struct goop *const                    io_goop);

#define __report_util_h__
#endif
